import type { ExtractPropTypes, PropType } from 'vue';
import type HeatmapLayer from './heatmap-layer.vue';
export declare const heatmapLayerProps: {
    /**
     * 每个热力点的'影响半径'，以px为单位,值越高，外观越平滑。
     * 若传入数组，则半径将与zoom级别关联
     * 例如:[1,2,14,50] 表示zoom为1/14时，radius为2/50
     */
    /**
     * The 'influence radius' of each thermal point, in px. The higher the value, the smoother the appearance.
     * If an array is passed, the radius will be associated with the zoom level
     * For example: [1,2,14,50] means that when the zoom is 1/14, the radius is 2/50
     */
    radius: {
        type: PropType<number | number[]>;
        default: number;
    };
    /**
     * 用于定义热力点对热力图贡献的权重,值为10时表示对一个热力点重绘10次
     * 若设置为数组，则表示基于目标属性值的线性变化
     * 例如['mag',0,0,6,1]表示对每个热力点的mag属性取值，其值为0时权重为0，值为6或大于6时权重为1
     */
    /**
     * Used to define the weight of the heat point's contribution to the heat map. A value of 10 means redrawing a heat point 10 times
     * If set to an array, it means a linear change based on the target attribute value
     * For example, ['mag',0,0,6,1] means taking the mag attribute value of each heat point. When the value is 0, the weight is 0, and when the value is 6 or greater, the weight is 1
     */
    weight: {
        type: PropType<number | (string | number)[]>;
        default: number;
    };
    /**
     * 强度，强度越高，热力点对展现效果的影响越大
     * 若设置为数组，则强度值将于zoom级别关联
     * 例如：[1,3,10,5],表示zoom为1/10时，对应的强度值为3/5
     */
    /**
     * Intensity. The higher the intensity, the greater the impact of the hot spot on the display effect
     * If set to an array, the intensity value will be associated with the zoom level
     * For example: [1,3,10,5], means that when the zoom is 1/10, the corresponding intensity value is 3/5
     */
    intensity: {
        type: PropType<number | number[]>;
        default: number;
    };
    /**
     * 颜色值，默认设置与热力点密度相关
     * Color value, the default setting is related to the density of the heat point
     */
    color: {
        type: PropType<(string | number)[]>;
        default: () => (string | number)[];
    };
    /**
     * 透明度，默认值为1
     * 若设置为数组，则与zoom关联
     * 例如：[7,1,9,0]表示0~7级透明度为1，9以上透明度为0
     */
    /**
     * opacity, default value is 1
     * If set to an array, it is associated with zoom
     * For example: [7,1,9,0] means that the opacity level 0 to 7 is 1, and the opacity level above 9 is 0
     */
    opacity: {
        type: PropType<number | number[]>;
        default: number;
    };
    id: {
        type: StringConstructor;
        default: () => string;
    };
    beforeId: StringConstructor;
    maxzoom: {
        type: NumberConstructor; /**
         * The 'influence radius' of each thermal point, in px. The higher the value, the smoother the appearance.
         * If an array is passed, the radius will be associated with the zoom level
         * For example: [1,2,14,50] means that when the zoom is 1/14, the radius is 2/50
         */
        default: number;
    };
    minzoom: {
        type: NumberConstructor;
        default: number;
    };
    show: {
        type: BooleanConstructor;
        default: boolean;
    };
    sourceId: StringConstructor;
    sourceLayerName: StringConstructor;
    geoJsonDataSource: PropType<string | import("mapbox-gl").GeoJSONSource>;
    data: PropType<import("../..").VectorLayerData | import("../..").SymbolLayerData>;
    pickable: {
        type: BooleanConstructor;
        default: boolean;
    };
    useExpression: BooleanConstructor;
    bufferSize: {
        type: NumberConstructor;
        default: number;
    };
    generateId: BooleanConstructor;
    autoHighlight: BooleanConstructor;
    highlightColor: {
        type: PropType<string | number[]>;
        default: () => number[];
    };
    cluster: BooleanConstructor;
    clusterRadius: NumberConstructor;
    clusterMinPoints: NumberConstructor;
    clusterMaxZoom: NumberConstructor;
};
export type HeatmapLayerProps = ExtractPropTypes<typeof heatmapLayerProps>;
export declare const heatmapLayerEmits: {
    created: () => boolean;
    click: ({ pixel, mouseCoordinates, coordinates, properties, originalEvent, }: {
        pixel: number[];
        mouseCoordinates: number[];
        coordinates: number[];
        properties: Record<string, any> | null;
        originalEvent: MouseEvent;
    }) => boolean;
    mousemove: ({ pixel, mouseCoordinates, coordinates, properties, originalEvent, }: {
        pixel: number[];
        mouseCoordinates: number[];
        coordinates: number[];
        properties: Record<string, any> | null;
        originalEvent: MouseEvent;
    }) => boolean;
    mouseleave: (event: import("mapbox-gl").MapMouseEvent) => boolean;
};
export type HeatmapLayerEmits = typeof heatmapLayerEmits;
export type HeatmapLayerInstance = InstanceType<typeof HeatmapLayer>;
